use std::path::PathBuf;

pub mod config;
pub mod db;
pub mod soundcloud;
pub mod youtube;
pub mod yt_dlp;

pub fn ensure_dir_exists(dir_path: &PathBuf) {
    let path = std::path::Path::new(dir_path);
    if !path.exists() {
        std::fs::create_dir_all(path).unwrap();
    }
}

pub enum Module {
    Soundcloud(soundcloud::SoundCloudModule),
    YouTube(youtube::YouTubeModule),
    YtDlp(yt_dlp::YtDlpModule),
}

impl Module {
    pub fn name(&self) -> String {
        match self {
            Module::Soundcloud(sound_cloud_module) => sound_cloud_module.name(),
            Module::YouTube(you_tube_module) => you_tube_module.name(),
            Module::YtDlp(yt_dlp_module) => yt_dlp_module.name(),
        }
    }

    pub fn run(&self) {
        match self {
            Module::Soundcloud(sound_cloud_module) => sound_cloud_module.run(),
            Module::YouTube(you_tube_module) => you_tube_module.run(),
            Module::YtDlp(yt_dlp_module) => yt_dlp_module.run(),
        }
    }
}
